<?php

namespace Moblyze\Briefing\Policies;

use Litepie\User\Contracts\UserPolicy;
use Moblyze\Briefing\Models\Breifing;

class BreifingPolicy
{

    /**
     * Determine if the given user can view the breifing.
     *
     * @param UserPolicy $user
     * @param Breifing $breifing
     *
     * @return bool
     */
    public function view(UserPolicy $user, Breifing $breifing)
    {
        if ($user->canDo('briefing.breifing.view') && $user->isAdmin()) {
            return true;
        }

        return $breifing->user_id == user_id() && $breifing->user_type == user_type();
    }

    /**
     * Determine if the given user can create a breifing.
     *
     * @param UserPolicy $user
     * @param Breifing $breifing
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('briefing.breifing.create');
    }

    /**
     * Determine if the given user can update the given breifing.
     *
     * @param UserPolicy $user
     * @param Breifing $breifing
     *
     * @return bool
     */
    public function update(UserPolicy $user, Breifing $breifing)
    {
        if ($user->canDo('briefing.breifing.edit') && $user->isAdmin()) {
            return true;
        }

        return $breifing->user_id == user_id() && $breifing->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given breifing.
     *
     * @param UserPolicy $user
     * @param Breifing $breifing
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Breifing $breifing)
    {
        return $breifing->user_id == user_id() && $breifing->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given breifing.
     *
     * @param UserPolicy $user
     * @param Breifing $breifing
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Breifing $breifing)
    {
        if ($user->canDo('briefing.breifing.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given breifing.
     *
     * @param UserPolicy $user
     * @param Breifing $breifing
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Breifing $breifing)
    {
        if ($user->canDo('briefing.breifing.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
