<?php

namespace Moblyze\Briefing\Providers;

use Illuminate\Support\ServiceProvider;

class BriefingServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'briefing');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'briefing');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerBriefing();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerBriefing()
    {
        $this->app->bind('briefing', function($app) {
            return new Briefing($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Briefing', 'Lavalite\Briefing\Facades\Briefing');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('moblyze.briefing', function ($app) {
            return $this->app->make('Moblyze\Briefing\Briefing');
        });

                // Bind Breifing to repository
        $this->app->bind(
            'Moblyze\Briefing\Interfaces\BreifingRepositoryInterface',
            \Moblyze\Briefing\Repositories\Eloquent\BreifingRepository::class
        );

        $this->app->register(\Moblyze\Briefing\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Moblyze\Briefing\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and briefing's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'moblyze.briefing'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeBriefing::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['moblyze.briefing'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('moblyze/briefing.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/briefing')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/briefing')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
